det-keygen
This crate implements an experimental port of the Python reference implementation of C2SP’s ECDSA Deterministic Key Generation.
This specification enables the derivation of ECDSA private keys from arbitrary seeds (using FIPS 186-5 methods only) which should contain at least 192 bits of entropy.
Examples
// Generate a P-256 private key based on a 160-bit seed
use det_keygen::{Keygen, P256};
let seed = b"When in doubt, don't";
let keygen = Keygen::<P256>::new(seed);
let key = keygen.generate();Structs
- Keygen
- Keygen derives a key for a curve following the c2sp.org/det-keygen.
- P256
- P-256 Curve implementation.
Traits
- Curve
- Curve describes an implementation independent description of an elliptic curve.